@@ -90,6 +90,7 @@ class ColumnPropertySchema(AttrsSchema):
 class ColumnNTile:
     key: str
     column_name: str
+    created_at: int
     frequency: int
     left_bound: str
     right_bound: str
@@ -102,6 +103,24 @@ class ColumnNTileSchema(AttrsSchema):
         register_as_scheme = True
 
 
+@attr.s(auto_attribs=True, kw_only=True)
+class SimilarColumn:
+    key: str
+    name: str
+    description: Optional[str] = None
+    col_type: str
+    sort_order: Optional[int] = None
+    table_name: str
+    table_type: str
+    table_schema: str
+
+
+class SimilarColumnSchema(AttrsSchema):
+    class Meta:
+        target = SimilarColumn
+        register_as_scheme = True
+
+
 @attr.s(auto_attribs=True, kw_only=True)
 class Column:
     name: str
@@ -116,6 +135,7 @@ class Column:
     column_references: Optional[List[ColumnReference]] = None
     properties: Optional[List[ColumnProperty]] = None
     ntiles: Optional[List[ColumnNTile]] = None
+    owners: List[User] = []
     completeness: Optional[float] = None
 
 
@@ -210,6 +230,7 @@ class Table:
     unique_usage: Optional[int] = None
     quality: Optional[str] = None
     queries: Optional[List[Query]] = []
+    creation_query: Optional[Query] = None
 
 
 class TableSchema(AttrsSchema):
